"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HMAC = void 0;
const crypter_1 = require("../crypter");
const hasher_1 = require("../hasher");
class HMAC {
    key;
    hasher;
    constructor(key, hasher = new hasher_1.Sha512()) {
        this.key = key;
        this.hasher = hasher;
    }
    sign(message) {
        const hashedKey = this.hasher.hash(this.key);
        const opad = new Uint8Array(hashedKey.length).fill(0x5C);
        const ipad = new Uint8Array(hashedKey.length).fill(0x36);
        return this.hasher.hash(new Uint8Array([...(0, crypter_1.xor)(hashedKey, opad), ...this.hasher.hash((0, crypter_1.xor)(hashedKey, ipad)), ...message]));
    }
    verify(message, tag) {
        const expectedTag = this.sign(message);
        if (tag.length !== expectedTag.length)
            return false;
        for (let i = 0; i < tag.length; i++) {
            if (tag[i] !== expectedTag[i])
                return false;
        }
        return true;
    }
}
exports.HMAC = HMAC;
