"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const src_1 = require("../../src");
const testSrc_1 = require("../../src/testSrc");
describe('FirestorePath', () => {
    // eslint-disable-next-line @typescript-eslint/init-declarations
    let path;
    beforeEach(() => {
        path = new src_1.FirestorePath('users', 'john');
    });
    it('should append components to the path', () => {
        path.append('posts', '123');
        (0, testSrc_1.expect)(path.fullPath).to.be.equal('users/john/posts/123');
    });
    it('invalid component should throw an error', () => {
        (0, testSrc_1.expect)(() => {
            path.append('posts/123');
        }).to.throw('Invalid component: posts/123');
    });
    it('should return a new path with appended components', () => {
        const newPath = path.appending('posts', '123');
        (0, testSrc_1.expect)(newPath.fullPath).to.be.equal('users/john/posts/123');
        (0, testSrc_1.expect)(path.fullPath).to.be.equal('users/john');
    });
    it('should check if the path is empty', () => {
        (0, testSrc_1.expect)(path.isEmpty).to.be.equal(false);
        const emptyPath = new src_1.FirestorePath();
        (0, testSrc_1.expect)(emptyPath.isEmpty).to.be.equal(true);
    });
    it('should return the parent path', () => {
        (0, testSrc_1.expect)(path.parentPath.fullPath).to.be.equal('users');
        (0, testSrc_1.expect)(path.fullPath).to.be.equal('users/john');
    });
    it('parent path of root path should throw an error', () => {
        (0, testSrc_1.expect)(() => {
            new src_1.FirestorePath().parentPath;
        }).to.throw('Root path has no parent');
    });
    it('should return the last component of the path', () => {
        (0, testSrc_1.expect)(path.lastComponent).to.be.equal('john');
    });
    it('should return the full path', () => {
        (0, testSrc_1.expect)(path.fullPath).to.be.equal('users/john');
    });
});
